==> dyedvoid-1.0.3%2Bmc1.21.1-sources.jar: archives/tater/dyedvoid/DyedVoidItems.java <==
package archives.tater.dyedvoid;

import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1747;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_6862;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.item.*;

public class DyedVoidItems {

    private static class_1792 register(class_2960 identifier, class_1792 item) {
        return class_2378.method_10230(class_7923.field_41178, identifier, item);
    }

    private static class_1792 register(String path, class_1792 item) {
        return register(DyedVoid.id(path), item);
    }

    private static class_1792 registerBlockItem(class_2248 block, class_1792.class_1793 settings) {
        return class_2378.method_10230(class_7923.field_41178, class_7923.field_41175.method_10221(block), new class_1747(block, settings));
    }

    private static class_1792 registerBlockItem(class_2248 block) {
        return registerBlockItem(block, new class_1792.class_1793());
    }

    public static final class_1792 WHITE_VOID = registerBlockItem(DyedVoidBlocks.WHITE_VOID);
    public static final class_1792 LIGHT_GRAY_VOID = registerBlockItem(DyedVoidBlocks.LIGHT_GRAY_VOID);
    public static final class_1792 GRAY_VOID = registerBlockItem(DyedVoidBlocks.GRAY_VOID);
    public static final class_1792 BLACK_VOID = registerBlockItem(DyedVoidBlocks.BLACK_VOID);
    public static final class_1792 BROWN_VOID = registerBlockItem(DyedVoidBlocks.BROWN_VOID);
    public static final class_1792 RED_VOID = registerBlockItem(DyedVoidBlocks.RED_VOID);
    public static final class_1792 ORANGE_VOID = registerBlockItem(DyedVoidBlocks.ORANGE_VOID);
    public static final class_1792 YELLOW_VOID = registerBlockItem(DyedVoidBlocks.YELLOW_VOID);
    public static final class_1792 LIME_VOID = registerBlockItem(DyedVoidBlocks.LIME_VOID);
    public static final class_1792 GREEN_VOID = registerBlockItem(DyedVoidBlocks.GREEN_VOID);
    public static final class_1792 CYAN_VOID = registerBlockItem(DyedVoidBlocks.CYAN_VOID);
    public static final class_1792 LIGHT_BLUE_VOID = registerBlockItem(DyedVoidBlocks.LIGHT_BLUE_VOID);
    public static final class_1792 BLUE_VOID = registerBlockItem(DyedVoidBlocks.BLUE_VOID);
    public static final class_1792 PURPLE_VOID = registerBlockItem(DyedVoidBlocks.PURPLE_VOID);
    public static final class_1792 MAGENTA_VOID = registerBlockItem(DyedVoidBlocks.MAGENTA_VOID);
    public static final class_1792 PINK_VOID = registerBlockItem(DyedVoidBlocks.PINK_VOID);

    public static final class_1792 END_VOID = registerBlockItem(DyedVoidBlocks.END_VOID);

    public static final class_1792[] VOID_BLOCKS = {
            BLACK_VOID,
            WHITE_VOID,
            LIGHT_GRAY_VOID,
            GRAY_VOID,
            BROWN_VOID,
            RED_VOID,
            ORANGE_VOID,
            YELLOW_VOID,
            LIME_VOID,
            GREEN_VOID,
            CYAN_VOID,
            LIGHT_BLUE_VOID,
            BLUE_VOID,
            PURPLE_VOID,
            MAGENTA_VOID,
            PINK_VOID,
            END_VOID
    };

    public static final class_1792 VOID_BOTTLE_ITEM = register("void_bottle", new VoidBottleItem(new class_1792.class_1793()
            .method_7889(16)
            .method_7896(class_1802.field_8469)
    ));

    public static final class_1761 ITEM_GROUP = FabricItemGroup.builder()
            .method_47320(() -> new class_1799(RED_VOID))
            .method_47321(class_2561.method_43471("itemGroup.dyedvoid.group"))
            .method_47317((context, entries) -> {
                entries.method_45421(VOID_BOTTLE_ITEM);
                entries.method_45421(WHITE_VOID);
                entries.method_45421(LIGHT_GRAY_VOID);
                entries.method_45421(GRAY_VOID);
                entries.method_45421(BLACK_VOID);
                entries.method_45421(BROWN_VOID);
                entries.method_45421(RED_VOID);
                entries.method_45421(ORANGE_VOID);
                entries.method_45421(YELLOW_VOID);
                entries.method_45421(LIME_VOID);
                entries.method_45421(GREEN_VOID);
                entries.method_45421(CYAN_VOID);
                entries.method_45421(LIGHT_BLUE_VOID);
                entries.method_45421(BLUE_VOID);
                entries.method_45421(PURPLE_VOID);
                entries.method_45421(MAGENTA_VOID);
                entries.method_45421(PINK_VOID);
                entries.method_45421(END_VOID);
            })
            .method_47324();

    public static final class_1792 DUMMY_END_PORTAL = register(class_2960.method_60656("dyedvoid/dummy/end_portal"), new class_1747(class_2246.field_10027, new class_1792.class_1793()));
    public static final class_1792 DUMMY_END_GATEWAY = register(class_2960.method_60656("dyedvoid/dummy/end_gateway"), new class_1747(class_2246.field_10613, new class_1792.class_1793()));

    public static final class_6862<class_1792> NO_GRAVITY_TAG = class_6862.method_40092(class_7924.field_41197, DyedVoid.id("no_gravity"));

    public static void initalize() {
        class_2378.method_10230(class_7923.field_44687, DyedVoid.id("item_group"), DyedVoidItems.ITEM_GROUP);
    }
}

==> dyedvoid-1.0.4%2Bmc1.21.10-sources.jar: archives/tater/dyedvoid/DyedVoidItems.java <==
package archives.tater.dyedvoid;

import archives.tater.dyedvoid.consumeeffect.ExhaustConsumeEffect;
import archives.tater.dyedvoid.consumeeffect.SetAirConsumeEffect;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_10124;
import net.minecraft.class_10132;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1747;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_9334;
import net.minecraft.item.*;
import java.util.List;
import java.util.function.Function;

public class DyedVoidItems {

    private static class_1792 register(class_2960 identifier, Function<class_1792.class_1793, class_1792> item, class_1792.class_1793 settings) {
        var key = class_5321.method_29179(class_7924.field_41197, identifier);
        return class_2378.method_39197(class_7923.field_41178, key, item.apply(settings.method_63686(key)));
    }

    private static class_1792 register(String path, Function<class_1792.class_1793, class_1792> item, class_1792.class_1793 settings) {
        return register(DyedVoid.id(path), item, settings);
    }

    private static class_1792 register(String path, class_1792.class_1793 settings) {
        return register(DyedVoid.id(path), class_1792::new, settings);
    }

    private static class_1792 registerBlockItem(class_2248 block) {
        return class_1802.method_7989(block);
    }

    private static class_1792 registerBlockItem(class_2960 identifier, class_2248 block) {
        return register(identifier, settings -> new class_1747(block, settings), new class_1792.class_1793());
    }

    public static final class_1792 WHITE_VOID = registerBlockItem(DyedVoidBlocks.WHITE_VOID);
    public static final class_1792 LIGHT_GRAY_VOID = registerBlockItem(DyedVoidBlocks.LIGHT_GRAY_VOID);
    public static final class_1792 GRAY_VOID = registerBlockItem(DyedVoidBlocks.GRAY_VOID);
    public static final class_1792 BLACK_VOID = registerBlockItem(DyedVoidBlocks.BLACK_VOID);
    public static final class_1792 BROWN_VOID = registerBlockItem(DyedVoidBlocks.BROWN_VOID);
    public static final class_1792 RED_VOID = registerBlockItem(DyedVoidBlocks.RED_VOID);
    public static final class_1792 ORANGE_VOID = registerBlockItem(DyedVoidBlocks.ORANGE_VOID);
    public static final class_1792 YELLOW_VOID = registerBlockItem(DyedVoidBlocks.YELLOW_VOID);
    public static final class_1792 LIME_VOID = registerBlockItem(DyedVoidBlocks.LIME_VOID);
    public static final class_1792 GREEN_VOID = registerBlockItem(DyedVoidBlocks.GREEN_VOID);
    public static final class_1792 CYAN_VOID = registerBlockItem(DyedVoidBlocks.CYAN_VOID);
    public static final class_1792 LIGHT_BLUE_VOID = registerBlockItem(DyedVoidBlocks.LIGHT_BLUE_VOID);
    public static final class_1792 BLUE_VOID = registerBlockItem(DyedVoidBlocks.BLUE_VOID);
    public static final class_1792 PURPLE_VOID = registerBlockItem(DyedVoidBlocks.PURPLE_VOID);
    public static final class_1792 MAGENTA_VOID = registerBlockItem(DyedVoidBlocks.MAGENTA_VOID);
    public static final class_1792 PINK_VOID = registerBlockItem(DyedVoidBlocks.PINK_VOID);

    public static final class_1792 END_VOID = registerBlockItem(DyedVoidBlocks.END_VOID);

    public static final class_1792[] VOID_BLOCKS = {
            BLACK_VOID,
            WHITE_VOID,
            LIGHT_GRAY_VOID,
            GRAY_VOID,
            BROWN_VOID,
            RED_VOID,
            ORANGE_VOID,
            YELLOW_VOID,
            LIME_VOID,
            GREEN_VOID,
            CYAN_VOID,
            LIGHT_BLUE_VOID,
            BLUE_VOID,
            PURPLE_VOID,
            MAGENTA_VOID,
            PINK_VOID,
            END_VOID
    };

    public static final class_1792 VOID_BOTTLE_ITEM = register("void_bottle", new class_1792.class_1793()
            .method_7889(16)
            .method_7896(class_1802.field_8469)
            .method_62834(class_1802.field_8469)
            .method_57349(class_9334.field_53964, new class_10124(1.6f, class_1839.field_8946, class_7923.field_41172.method_47983(class_3417.field_42593), false, List.of(
                    new class_10132(new class_1293(class_1294.field_5902, 200)),
                    new ExhaustConsumeEffect(12),
                    new SetAirConsumeEffect(0)
            )))
    );

    public static final class_1761 ITEM_GROUP = FabricItemGroup.builder()
            .method_47320(() -> new class_1799(RED_VOID))
            .method_47321(class_2561.method_43471("itemGroup.dyedvoid.group"))
            .method_47317((context, entries) -> {
                entries.method_45421(VOID_BOTTLE_ITEM);
                entries.method_45421(WHITE_VOID);
                entries.method_45421(LIGHT_GRAY_VOID);
                entries.method_45421(GRAY_VOID);
                entries.method_45421(BLACK_VOID);
                entries.method_45421(BROWN_VOID);
                entries.method_45421(RED_VOID);
                entries.method_45421(ORANGE_VOID);
                entries.method_45421(YELLOW_VOID);
                entries.method_45421(LIME_VOID);
                entries.method_45421(GREEN_VOID);
                entries.method_45421(CYAN_VOID);
                entries.method_45421(LIGHT_BLUE_VOID);
                entries.method_45421(BLUE_VOID);
                entries.method_45421(PURPLE_VOID);
                entries.method_45421(MAGENTA_VOID);
                entries.method_45421(PINK_VOID);
                entries.method_45421(END_VOID);
            })
            .method_47324();

//    public static final Item DUMMY_END_PORTAL = registerBlockItem(Identifier.ofVanilla("dyedvoid/dummy/end_portal"), Blocks.END_PORTAL);
//    public static final Item DUMMY_END_GATEWAY = registerBlockItem(Identifier.ofVanilla("dyedvoid/dummy/end_gateway"), Blocks.END_GATEWAY);

    public static final class_6862<class_1792> NO_GRAVITY_TAG = class_6862.method_40092(class_7924.field_41197, DyedVoid.id("no_gravity"));

    public static void initalize() {
        class_2378.method_10230(class_7923.field_44687, DyedVoid.id("item_group"), DyedVoidItems.ITEM_GROUP);

        class_2378.method_10230(class_7923.field_53967, DyedVoid.id("set_air"), SetAirConsumeEffect.TYPE);
        class_2378.method_10230(class_7923.field_53967, DyedVoid.id("exhaust"), ExhaustConsumeEffect.TYPE);
    }
}
